"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.themeWithKnobs = themeWithKnobs;

var _react = _interopRequireDefault(require("react"));

var _addonKnobs = require("@storybook/addon-knobs");

var _2 = require("..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var Group;

(function (Group) {
  Group["TextFields"] = "Text fields";
  Group["Selects"] = "Selects";
  Group["Breadcrumbs"] = "Breadcrumbs";
  Group["Actions"] = "Actions";
  Group["HeadingsLevel1"] = "Headings level 1";
  Group["HeadingsLevel2"] = "Headings level 2";
  Group["HeadingsLevel3"] = "Headings level 3";
  Group["Checkbox"] = "Checkbox";
})(Group || (Group = {}));

var Label;

(function (Label) {
  Label["Border"] = "Border";
  Label["LabelPosition"] = "Label position";
})(Label || (Label = {}));

var Action;

(function (Action) {
  Action["Display"] = "Display";
})(Action || (Action = {}));

var Breadcrumb;

(function (Breadcrumb) {
  Breadcrumb["Gap"] = "Gap";
  Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
  Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));

var SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
var BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
var LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
var ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
var BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
var NUMBER_STYLE_OPTIONS = optionify(['none', 'decimal', 'decimalLeadingZero']);
var STYLE_OPTIONS = optionify(['style1', 'style2', 'style3', 'style4', 'style5', 'style6', 'style7', 'style8', 'style9']);
var SIZE_OPTIONS = optionify(['base', 'xsmall', 'small', 'medium', 'large', 'xlarge', 'xxlarge']);
var LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
var FONT_OPTIONS = optionify(['primary', 'secondary']);
var WEIGHT_OPTIONS = optionify(['base', 'bold']);
var LINE_SIZE_OPTIONS = optionify(['base', 'large']);
var KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);

function themeWithKnobs() {
  for (var _len = arguments.length, picks = new Array(_len), _key = 0; _key < _len; _key++) {
    picks[_key] = arguments[_key];
  }

  return function (storyFn) {
    return /*#__PURE__*/_react["default"].createElement(ThemeWithKnobs, {
      pick: picks
    }, storyFn());
  };
}

function ThemeWithKnobs(_ref) {
  var _ref$pick = _ref.pick,
      pick = _ref$pick === void 0 ? [] : _ref$pick,
      children = _ref.children;
  var textFieldsBorder;
  var selectBorder;
  var textFieldsLabelPosition;
  var selectLabelPosition;
  var actionsDisplay;
  var breadcrumbGap;
  var chevronIconSeparator = true;
  var numberStyle;
  var breadcrumbStyle;
  var headingLevel1Style;
  var headingLevel2Style;
  var headingLevel3Style;
  var checkboxBorderRadius;

  if (pick.includes('textFields')) {
    textFieldsBorder = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, textFieldsBorder, Group.TextFields);
    textFieldsLabelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFieldsLabelPosition, Group.TextFields);
  }

  if (pick.includes('select')) {
    selectBorder = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, selectBorder, Group.Selects);
    selectLabelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, selectLabelPosition, Group.Selects);
  }

  if (pick.includes('actions')) {
    actionsDisplay = (0, _addonKnobs.select)(Action.Display, ACTIONS_DISPLAY_OPTIONS, actionsDisplay, Group.Actions);
  }

  if (pick.includes('buyerJourney')) {
    breadcrumbGap = (0, _addonKnobs.select)(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, breadcrumbGap, Group.Breadcrumbs);
    chevronIconSeparator = (0, _addonKnobs["boolean"])(Breadcrumb.ChevronIconSeparator, chevronIconSeparator, Group.Breadcrumbs);
    numberStyle = (0, _addonKnobs.select)(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, numberStyle, Group.Breadcrumbs);
    breadcrumbStyle = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, breadcrumbStyle, Group.Breadcrumbs);
  }

  if (pick.includes('checkbox')) {
    checkboxBorderRadius = (0, _addonKnobs.select)('Border radius', SIMPLE_BORDER_RADIUS_OPTIONS, checkboxBorderRadius, Group.Checkbox);
  }

  if (pick.includes('headingLevel1')) {
    headingLevel1Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel1Style, Group.HeadingsLevel1);
  }

  if (pick.includes('headingLevel2')) {
    headingLevel2Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel2Style, Group.HeadingsLevel2);
  }

  if (pick.includes('headingLevel3')) {
    headingLevel3Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel3Style, Group.HeadingsLevel3);
  }

  var typographyStyles = _toConsumableArray(Array(9)).reduce(function (acc, _, index) {
    var oneBasedIndex = index + 1;
    return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, "typographyStyle".concat(oneBasedIndex), {
      size: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " size"), SIZE_OPTIONS, undefined, 'Styles'),
      letterCase: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " letter case"), LETTER_CASE_OPTIONS, undefined, 'Styles'),
      fonts: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " fonts"), FONT_OPTIONS, undefined, 'Styles'),
      weight: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " weight"), WEIGHT_OPTIONS, undefined, 'Styles'),
      lineSize: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " line size"), LINE_SIZE_OPTIONS, undefined, 'Styles'),
      kerning: (0, _addonKnobs.select)("Style ".concat(oneBasedIndex, " kerning"), KERNING_OPTIONS, undefined, 'Styles')
    }));
  }, {});

  var theme = (0, _2.createTheme)(_objectSpread(_objectSpread({
    textFields: {
      border: textFieldsBorder,
      labelPosition: textFieldsLabelPosition
    },
    select: {
      border: selectBorder,
      labelPosition: selectLabelPosition
    },
    actions: {
      display: actionsDisplay
    },
    buyerJourney: {
      gap: breadcrumbGap,
      chevronIconSeparator: chevronIconSeparator,
      numberStyle: numberStyle,
      typographyStyle: breadcrumbStyle
    },
    headingLevel1: {
      typographyStyle: headingLevel1Style
    },
    headingLevel2: {
      typographyStyle: headingLevel2Style
    },
    headingLevel3: {
      typographyStyle: headingLevel3Style
    }
  }, typographyStyles), {}, {
    checkbox: {
      borderRadius: checkboxBorderRadius
    }
  }));
  return /*#__PURE__*/_react["default"].createElement(_2.Theme, {
    theme: theme
  }, children);
}

function optionify(array) {
  return array.reduce(function (acc, value) {
    return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, value, value));
  }, {
    ' ': undefined
  });
}