import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Button } from '../Button';
import { Banner } from './Banner';
var defaultProps = {
  title: 'There was an error'
};
describe('<Banner />', function () {
  describe('title', function () {
    it('render its children', function () {
      var title = 'There was an error.';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, {
        title: title
      }));
      expect(banner).toContainReactText(title);
    });
  });
  describe('status', function () {
    it('renders the right <Icon />', function () {
      var status = 'critical';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(Icon, {
        source: status
      });
    });
  });
  describe('collapsible', function () {
    it('renders a collapsible button if collapsible', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent(Button, {
        plain: true
      });
    });
    it('displays chevronDown collapsible button icon by default', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent(Icon, {
        source: 'chevronDown'
      });
    });
    it('displays chevronUp collapsible button icon on press', function () {
      var _banner$find;

      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      (_banner$find = banner.find(Button)) === null || _banner$find === void 0 ? void 0 : _banner$find.trigger('onPress');
      expect(banner).toContainReactComponent(Icon, {
        source: 'chevronUp'
      });
    });
    it('hides the children by default', function () {
      function Child() {
        return /*#__PURE__*/React.createElement("div", null);
      }

      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/React.createElement(Child, null)));
      expect(banner).not.toContainReactComponent(Child);
    });
    it('displays the children on press', function () {
      var _banner$find2;

      function Child() {
        return /*#__PURE__*/React.createElement("div", null);
      }

      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/React.createElement(Child, null)));
      (_banner$find2 = banner.find(Button)) === null || _banner$find2 === void 0 ? void 0 : _banner$find2.trigger('onPress');
      expect(banner).toContainReactComponent(Child);
    });
  });
  describe('iconHidden', function () {
    it('renders the <Icon /> by default', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps));
      expect(banner).toContainReactComponent(Icon);
    });
    it('does not renders the <Icon /> when iconHidden is set', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        iconHidden: true
      })));
      expect(banner).not.toContainReactComponent(Icon);
    });
  });
});