import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import faker from 'faker';
import { TextBlock } from '../TextBlock';
import { MoneyLine } from './MoneyLine';
var defaultProps = {
  label: faker.random.word(),
  value: faker.random.number().toString()
};
describe('<MoneyLine />', function () {
  it('renders a label', function () {
    var label = faker.random.word();
    var moneyLine = mount( /*#__PURE__*/React.createElement(MoneyLine, Object.assign({}, defaultProps, {
      label: label
    })));
    expect(moneyLine).toContainReactText(label);
  });
  it('renders a value', function () {
    var value = faker.random.number().toString();
    var moneyLine = mount( /*#__PURE__*/React.createElement(MoneyLine, Object.assign({}, defaultProps, {
      value: value
    })));
    expect(moneyLine).toContainReactText(value);
  });
  it('renders a subdued value if subdued', function () {
    var value = faker.random.number().toString();
    var moneyLine = mount( /*#__PURE__*/React.createElement(MoneyLine, Object.assign({}, defaultProps, {
      value: value,
      subdued: true
    })));
    expect(moneyLine).toContainReactComponent(TextBlock, {
      subdued: true,
      children: value
    });
  });
  it('renders its children', function () {
    function Child() {
      return /*#__PURE__*/React.createElement("div", null);
    }

    var moneyLine = mount( /*#__PURE__*/React.createElement(MoneyLine, defaultProps, /*#__PURE__*/React.createElement(Child, null)));
    expect(moneyLine).toContainReactComponent(Child);
  });
});