import React, { useRef, useMemo } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { Heading } from '../Heading';
import { VisuallyHidden } from '../VisuallyHidden';
import { useThemeConfiguration } from '../Theme';
import { OptionListContext } from './context';
import styles from './OptionList.css';
export function OptionList(_ref) {
  var id = _ref.id,
      selectedItems = _ref.selectedItems,
      onChange = _ref.onChange,
      title = _ref.title,
      titleHidden = _ref.titleHidden,
      _ref$allowMultiple = _ref.allowMultiple,
      allowMultiple = _ref$allowMultiple === void 0 ? false : _ref$allowMultiple,
      children = _ref.children;
  var onChangeRef = useRef(onChange);
  onChangeRef.current = onChange;
  var contextValue = useMemo(function () {
    return {
      id: id,
      selectedItems: selectedItems,
      allowMultiple: allowMultiple,

      get onChange() {
        return onChangeRef.current;
      }

    };
  }, [allowMultiple, id, selectedItems]);
  var titleMarkup = title && (titleHidden ? /*#__PURE__*/React.createElement(VisuallyHidden, null, /*#__PURE__*/React.createElement("legend", null, title)) : /*#__PURE__*/React.createElement("legend", {
    className: styles.Title
  }, /*#__PURE__*/React.createElement(Heading, {
    level: 3,
    role: "presentation"
  }, title)));

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.optionList,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.background,
      background = _useThemeConfiguratio3 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.gap,
      gap = _useThemeConfiguratio4 === void 0 ? 'none' : _useThemeConfiguratio4;

  var className = classNames(styles.OptionList, background && styles[variationName('OptionList-background', background)], gap === 'none' && styles.isContainer);
  return /*#__PURE__*/React.createElement(OptionListContext.Provider, {
    value: contextValue
  }, /*#__PURE__*/React.createElement("fieldset", null, titleMarkup, /*#__PURE__*/React.createElement("div", {
    className: className
  }, children)));
}