import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { VisuallyHidden } from '../VisuallyHidden';
import { HiddenForAccessibility } from '../HiddenForAccessibility';
import { Radio } from './Radio';
var defaultProps = {
  name: 'radio_button',
  children: 'Save this information for next time'
};
describe('<Radio />', function () {
  it('renders an un-checked radio and label', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, defaultProps));
    expect(radio).toContainReactComponent('input', {
      checked: false,
      type: 'radio'
    });
    expect(radio.find('label')).toContainReactText('Save this information for next time');
  });
  it('renders a checked radio when the checked prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
      checked: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a checked radio when the value prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
      value: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a disabled radio when the disabled prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
      disabled: true
    })));
    expect(radio).toContainReactComponent('input', {
      disabled: true,
      type: 'radio'
    });
  });
  it('calls the onChange callback when the radio is checked and unchecked', function () {
    var onChangeSpy = jest.fn();
    var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
      onChange: onChangeSpy
    })));
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: true
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(true);
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: false
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(false);
  });
  describe('accessibilityLabel', function () {
    it('renders visually hidden content when the accessibilityLabel is set', function () {
      var accessibilityLabelContent = 'Accessibility content';
      var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
        accessibilityLabel: accessibilityLabelContent
      })));
      expect(radio.find(VisuallyHidden)).toContainReactText(accessibilityLabelContent);
    });
    it('hides the label for accessibility purposes when the accessibilityLabel is set', function () {
      var children = 'Basic label';
      var radio = mountWithContext( /*#__PURE__*/React.createElement(Radio, Object.assign({}, defaultProps, {
        accessibilityLabel: "Accessibility content"
      }), children));
      expect(radio.find(HiddenForAccessibility)).toContainReactText(children);
    });
  });
});