"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _TextField = require("../TextField");

var _Labelled = require("../Labelled");

var _Autocomplete = require("./Autocomplete");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('../../utilities/focus', () => ({
  isFocused: jest.fn()
}));
const {
  isFocused
} = jest.requireMock('../../utilities/focus');
const defaultProps = {
  id: 'address',
  label: 'Address',
  name: 'address',
  options: ['address 1', 'address 2'],
  value: '',
  title: 'Suggestions',
  ariaLabel: 'Close Predictions'
};

const autocompleteOptions = options => {
  return /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteOptions, null, options && options.map(option => /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteOption, {
    key: option
  }, option)));
};

describe('<Autocomplete />', () => {
  beforeEach(() => {
    isFocused.mockReset();
    isFocused.mockImplementation(() => true);
  });
  describe('<Labelled />', () => {
    it('renders a <Labelled />', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_Labelled.Labelled);
    });
  });
  describe('<Field />', () => {
    it('renders a <Field />', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address'
      });
    });
    it('sets the default aria-controls and aria-expanded properties', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaExpanded: false
      });
    });
    it('sets the aria-controls, aria-activedescendant and aria-expanded when the input is focused', () => {
      var _autocomplete$find;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps));
      (_autocomplete$find = autocomplete.find(_TextField.Field)) === null || _autocomplete$find === void 0 ? void 0 : _autocomplete$find.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaActiveDescendant: 'address-option-0',
        ariaExpanded: true
      });
    });
    it('calls the onChange callback when the Field onChange is called', () => {
      var _autocomplete$find2;

      const onChangeSpy = jest.fn();
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      })));
      (_autocomplete$find2 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find2 === void 0 ? void 0 : _autocomplete$find2.trigger('onInput', 'address');
      expect(onChangeSpy.mock.calls).toMatchObject([['address']]);
      expect(onChangeSpy).toHaveBeenCalledTimes(1);
    });
  });
  describe('<AutocompleteOptions />', () => {
    it('renders when the input is focused', () => {
      var _autocomplete$find3;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find3 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find3 === void 0 ? void 0 : _autocomplete$find3.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_Autocomplete.AutocompleteOptions, {
        children: expect.any(Array)
      });
    });
    it('renders an <ul> with unique id', () => {
      var _autocomplete$find4;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find4 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find4 === void 0 ? void 0 : _autocomplete$find4.trigger('onFocus');
      expect(autocomplete).toContainReactComponent('ul', {
        id: 'address-options'
      });
    });
    it('is hidden when the close button is clicked', () => {
      var _autocomplete$find5, _autocomplete$find6;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find5 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find5 === void 0 ? void 0 : _autocomplete$find5.trigger('onFocus');
      (_autocomplete$find6 = autocomplete.find('button')) === null || _autocomplete$find6 === void 0 ? void 0 : _autocomplete$find6.trigger('onClick');
      expect(autocomplete).not.toContainReactComponent(_Autocomplete.AutocompleteOptions);
    });
  });
  describe('<AutocompleteOption />', () => {
    it('selects the first option when focus is on field', () => {
      var _autocomplete$find7;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find7 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find7 === void 0 ? void 0 : _autocomplete$find7.trigger('onFocus');
      const [firstOption, secondOption] = autocomplete.findAll(_Autocomplete.AutocompleteOption);
      expect(firstOption.prop('isSelected')).toStrictEqual(true);
      expect(secondOption.prop('isSelected')).toStrictEqual(false);
    });
    it('renders a <li> with unique id', () => {
      var _autocomplete$find8;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find8 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find8 === void 0 ? void 0 : _autocomplete$find8.trigger('onFocus');
      const [firstOption, secondOption] = autocomplete.findAll(_Autocomplete.AutocompleteOption);
      expect(firstOption).toContainReactComponent('li', {
        id: 'address-option-0'
      });
      expect(secondOption).toContainReactComponent('li', {
        id: 'address-option-1'
      });
    });
  });
  describe('<AutocompleteFooter />', () => {
    it('renders when the input is focused', () => {
      var _autocomplete$find9;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteFooter, null, "This is a test footer"), ";"));
      (_autocomplete$find9 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find9 === void 0 ? void 0 : _autocomplete$find9.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_Autocomplete.AutocompleteFooter, {
        children: 'This is a test footer'
      });
    });
  });
});