"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePopper = usePopper;
exports.useRect = useRect;
exports.useEffectRect = useEffectRect;

var _react = require("react");

var _context = require("./context");

function usePopper() {
  const context = (0, _react.useContext)(_context.PopperContext);

  if (context === null) {
    throw new Error('No Popper in context');
  }

  return context;
}

function useRect() {
  const [rect, setRect] = (0, _react.useState)(null);
  const ref = (0, _react.useCallback)(node => {
    if (node !== null) {
      setRect(node.getBoundingClientRect());
    }
  }, []);
  return [rect, ref];
}

function useEffectRect(ref) {
  const [rect, setRect] = (0, _react.useState)(null);
  const setBoundingRect = (0, _react.useCallback)(() => {
    if (ref !== null) {
      setRect(ref.getBoundingClientRect());
    }
  }, [ref]);
  (0, _react.useLayoutEffect)(() => {
    setBoundingRect();
    window.addEventListener('resize', setBoundingRect);
    window.addEventListener('scroll', setBoundingRect);
    return () => {
      window.removeEventListener('resize', setBoundingRect);
      window.removeEventListener('scroll', setBoundingRect);
    };
  }, [setBoundingRect]);
  return rect;
}