"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utilities_1 = require("../../test-utilities");
const Icon_1 = require("../Icon");
const Button_1 = require("../Button");
const Banner_1 = require("./Banner");
const defaultProps = {
    title: 'There was an error',
};
describe('<Banner />', () => {
    describe('title', () => {
        it('render its children', () => {
            const title = 'There was an error.';
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner title={title}/>);
            expect(banner).toContainReactText(title);
        });
    });
    describe('status', () => {
        it('renders the right <Icon />', () => {
            const status = 'critical';
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} status={status}/>);
            expect(banner).toContainReactComponent(Icon_1.Icon, {
                source: status,
            });
        });
    });
    describe('collapsible', () => {
        it('renders a collapsible button if collapsible', () => {
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} collapsible/>);
            expect(banner).toContainReactComponent(Button_1.Button, {
                plain: true,
            });
        });
        it('displays chevronDown collapsible button icon by default', () => {
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} collapsible/>);
            expect(banner).toContainReactComponent(Icon_1.Icon, {
                source: 'chevronDown',
            });
        });
        it('displays chevronUp collapsible button icon on press', () => {
            var _a;
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} collapsible/>);
            (_a = banner.find(Button_1.Button)) === null || _a === void 0 ? void 0 : _a.trigger('onPress');
            expect(banner).toContainReactComponent(Icon_1.Icon, {
                source: 'chevronUp',
            });
        });
        it('hides the children by default', () => {
            function Child() {
                return <div />;
            }
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} collapsible>
          <Child />
        </Banner_1.Banner>);
            expect(banner).not.toContainReactComponent(Child);
        });
        it('displays the children on press', () => {
            var _a;
            function Child() {
                return <div />;
            }
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} collapsible>
          <Child />
        </Banner_1.Banner>);
            (_a = banner.find(Button_1.Button)) === null || _a === void 0 ? void 0 : _a.trigger('onPress');
            expect(banner).toContainReactComponent(Child);
        });
    });
    describe('iconHidden', () => {
        it('renders the <Icon /> by default', () => {
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps}/>);
            expect(banner).toContainReactComponent(Icon_1.Icon);
        });
        it('does not renders the <Icon /> when iconHidden is set', () => {
            const banner = test_utilities_1.mountWithContext(<Banner_1.Banner {...defaultProps} iconHidden/>);
            expect(banner).not.toContainReactComponent(Icon_1.Icon);
        });
    });
});
