"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const AppContext_1 = require("../AppContext");
const transition_1 = require("../../utilities/transition");
const Spinner_1 = require("../Spinner");
const Link_1 = require("../Link");
const legacy_1 = require("../../utilities/legacy");
const media_query_1 = require("../../utilities/media-query");
const Connected_1 = require("../Connected");
const Button_css_1 = __importDefault(require("./Button.css"));
function Button({ children, submit = false, disabled, onPress, to, subdued, plain, secondary, loading = false, fill = false, loadingLabel, }) {
    const href = disabled ? undefined : to;
    const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
    const translate = AppContext_1.useTranslate();
    const prefersReducedMotion = media_query_1.usePrefersReducedMotion();
    const transition = transition_1.useTransition(loading, {
        enter: 'slow',
    });
    const connected = Connected_1.useConnected();
    const classes = css_utilities_1.classNames(Button_css_1.default.Button, legacy_1.button, subdued && Button_css_1.default.isSubdued, plain && Button_css_1.default.isPlain, disabled && Button_css_1.default.isDisabled, loading && Button_css_1.default.isLoading, fill && Button_css_1.default.isFill, Button_css_1.default[css_utilities_1.variationName('isLoading-transition', transition)], connected && Button_css_1.default.isConnected, secondary && Button_css_1.default.isSecondary);
    const content = <span className={Button_css_1.default.Content}>{children}</span>;
    const type = submit ? 'submit' : 'button';
    const loadingMarkup = (<span className={css_utilities_1.classNames(Button_css_1.default.LoadingContent, !prefersReducedMotion && Button_css_1.default.Spinner)}>
      <Spinner_1.Spinner size="small" color="inherit">
        {loadingLabel ? loadingLabel : translate('processing')}
      </Spinner_1.Spinner>
    </span>);
    if (href) {
        return (<Link_1.UnstyledLink to={href} className={classes} onPress={onPress}>
        {content}
        {loading && loadingMarkup}
      </Link_1.UnstyledLink>);
    }
    return (<button type={type} className={classes} disabled={disabled || loading} onClick={onClick} aria-busy={loading}>
      {content}
      {loading && loadingMarkup}
    </button>);
}
exports.Button = Button;
