"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WarningCircleIcon = exports.CancelledCircleIcon = exports.CheckmarkCircleIcon = exports.CalloutHeader = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const CalloutHeader_css_1 = __importDefault(require("./CalloutHeader.css"));
const STATUS_ICONS = {
    success: <CheckmarkCircleIcon />,
    cancelled: <CancelledCircleIcon />,
    warning: <WarningCircleIcon />,
};
function CalloutHeader({ children, status, animated = true }) {
    const className = css_utilities_1.classNames(CalloutHeader_css_1.default.CalloutHeader, {
        [CalloutHeader_css_1.default.Animated]: animated,
    });
    return (<header className={className}>
      <div className={CalloutHeader_css_1.default.CalloutHeaderStatus}>{STATUS_ICONS[status]}</div>
      <div className={CalloutHeader_css_1.default.CalloutHeaderContent}>{children}</div>
    </header>);
}
exports.CalloutHeader = CalloutHeader;
function CheckmarkCircleIcon() {
    return (<svg width="50" height="50" viewBox="0 0 50 50" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M49 25C49 38.2548 38.2548 49 25 49C11.7452 49 1 38.2548 1 25C1 11.7452 11.7452 1 25 1C38.2548 1 49 11.7452 49 25Z" stroke="#197BBD" strokeWidth="2"/>
      <path d="M15 24.5113L22.3067 31.818L35.1247 19" stroke="#197BBD" strokeWidth="2"/>
    </svg>);
}
exports.CheckmarkCircleIcon = CheckmarkCircleIcon;
function CancelledCircleIcon() {
    return (<svg width="50" height="50" viewBox="0 0 50 50" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M49 25C49 38.2548 38.2548 49 25 49C11.7452 49 1 38.2548 1 25C1 11.7452 11.7452 1 25 1C38.2548 1 49 11.7452 49 25Z" stroke="#197BBD" strokeWidth="2"/>
      <path d="M39 12L11.9999 39" stroke="#197BBD" strokeWidth="2"/>
      <path d="M12 12L39.0001 39.0001" stroke="#197BBD" strokeWidth="2"/>
    </svg>);
}
exports.CancelledCircleIcon = CancelledCircleIcon;
function WarningCircleIcon() {
    return (<svg width="50" height="50" viewBox="0 0 50 50" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M49 25C49 38.2548 38.2548 49 25 49C11.7452 49 1 38.2548 1 25C1 11.7452 11.7452 1 25 1C38.2548 1 49 11.7452 49 25Z" stroke="#BBBBBB" strokeWidth="2"/>
      <path d="M25 11V30" stroke="#BBBBBB" strokeWidth="2" stroke-linecap="square"/>
      <path fill-rule="evenodd" clip-rule="evenodd" d="M25 39C25.8284 39 26.5 38.3284 26.5 37.5C26.5 36.6716 25.8284 36 25 36C24.1716 36 23.5 36.6716 23.5 37.5C23.5 38.3284 24.1716 39 25 39Z" fill="#BBBBBB"/>
    </svg>);
}
exports.WarningCircleIcon = WarningCircleIcon;
