"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepperStepConnector = exports.StepperStepLabel = exports.StepperStepIcon = exports.StepperStep = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Icon_1 = require("../../../Icon");
const TextBlock_1 = require("../../../TextBlock");
const VisuallyHidden_1 = require("../../../VisuallyHidden");
const hooks_1 = require("../../hooks");
const StepperStep_css_1 = __importDefault(require("./StepperStep.css"));
function StepperStep({ children, description, icon, iconColor, id, label, state, stateHidden = true, }) {
    const { steps } = hooks_1.useStepper();
    const first = Object.keys(steps).indexOf(id) === 0;
    const { [id]: { active, completed }, } = steps;
    const className = css_utilities_1.classNames(StepperStep_css_1.default.StepperStep, completed && StepperStep_css_1.default.Completed);
    return (<>
      {!first && <StepperStepConnector active={active} completed={completed}/>}
      <li className={className} aria-current={active}>
        <StepperStepIcon active={active} completed={completed} source={icon} color={iconColor}/>
        <StepperStepLabel active={active} completed={completed} description={description} label={label} state={state} stateHidden={stateHidden}/>
        {children}
      </li>
    </>);
}
exports.StepperStep = StepperStep;
function StepperStepIcon({ active, color = 'interactive', source, completed, }) {
    const className = css_utilities_1.classNames(StepperStep_css_1.default.StepperStepIcon, active && StepperStep_css_1.default.active, completed && StepperStep_css_1.default.completed);
    return (<div className={className}>
      <Icon_1.Icon source={source} color={active || completed ? color : 'subdued'} size="large"/>
    </div>);
}
exports.StepperStepIcon = StepperStepIcon;
function StepperStepLabel({ active, completed, description, label, state, stateHidden, }) {
    const className = css_utilities_1.classNames(StepperStep_css_1.default.StepperStepLabel, (active || completed) && StepperStep_css_1.default.completed);
    return (<>
      <div className={className}>
        {stateHidden ? (<VisuallyHidden_1.VisuallyHidden>{state}</VisuallyHidden_1.VisuallyHidden>) : (<TextBlock_1.TextBlock>{state}</TextBlock_1.TextBlock>)}
        <TextBlock_1.TextBlock emphasized={active || completed}>{label}</TextBlock_1.TextBlock>
      </div>
      {(active || completed) && description && (<TextBlock_1.TextBlock size="small" subdued>
          {description}
        </TextBlock_1.TextBlock>)}
    </>);
}
exports.StepperStepLabel = StepperStepLabel;
function StepperStepConnector({ active, completed, }) {
    const className = css_utilities_1.classNames(StepperStep_css_1.default.StepperStepConnector, (active || completed) && StepperStep_css_1.default.completed);
    return <li className={className} aria-hidden/>;
}
exports.StepperStepConnector = StepperStepConnector;
