"use strict";
/* eslint id-length: off */
Object.defineProperty(exports, "__esModule", { value: true });
exports.colorBorderEmphasized = exports.colorTextSubdued = exports.colorTextEmphasized = exports.UiTheme = exports.createTheme = exports.ThemeContext = void 0;
const react_1 = require("react");
const hsluv_1 = require("../../utilities/hsluv");
const modularScale_1 = require("./utilities/modularScale");
exports.ThemeContext = react_1.createContext(undefined);
function createTheme({ global = {}, buyerJourney = {}, typographyPrimary = {}, typographySecondary = {}, headingLevel1 = {}, headingLevel2 = {}, headingLevel3 = {}, controls = {}, label = {}, textFields = {}, select = {}, checkbox = {}, radio = {}, optionList = {}, reviewBlock = {}, actions = {}, lineItems = {}, typographyStyle1 = {}, typographyStyle2 = {}, typographyStyle3 = {}, typographyStyle4 = {}, typographyStyle5 = {}, typographyStyle6 = {}, typographyStyle7 = {}, typographyStyle8 = {}, typographyStyle9 = {}, colors, } = {}) {
    return new UiTheme({
        global,
        buyerJourney,
        typographyPrimary,
        typographySecondary,
        headingLevel1,
        headingLevel2,
        headingLevel3,
        controls,
        label,
        textFields,
        select,
        checkbox,
        radio,
        optionList,
        reviewBlock,
        actions,
        lineItems,
        typographyStyle1,
        typographyStyle2,
        typographyStyle3,
        typographyStyle4,
        typographyStyle5,
        typographyStyle6,
        typographyStyle7,
        typographyStyle8,
        typographyStyle9,
        colors,
    });
}
exports.createTheme = createTheme;
class UiTheme {
    constructor(configuration) {
        var _a, _b;
        this.listeners = {
            change: new Set(),
            preview: new Set(),
        };
        this.configuration = Object.assign(Object.assign({}, configuration), { colors: colorsFromOverrides((_a = configuration.colors) !== null && _a !== void 0 ? _a : {}), typographyScale: (_b = configuration.typographyScale) !== null && _b !== void 0 ? _b : {} });
        this.customProperties = customPropertiesFromThemeConfiguration(this.configuration);
    }
    preview(colors, typographyScale) {
        const colorsCustomProperties = customPropertiesFromRoleColors(colorsFromOverrides(colors));
        const typographyScaleCustomProperties = customPropertiesFromTypographyScale(typographyScale);
        for (const listener of this.listeners.preview) {
            listener(Object.assign(Object.assign({}, colorsCustomProperties), typographyScaleCustomProperties));
        }
    }
    set(key, value) {
        this.configuration = Object.assign(Object.assign({}, this.configuration), { [key]: value });
        for (const listener of this.listeners.change) {
            listener(this.configuration);
        }
        const customProperties = customPropertiesFromThemeConfiguration(this.configuration);
        for (const listener of this.listeners.preview) {
            listener(customProperties);
        }
    }
    on(event, listener) {
        this.listeners[event].add(listener);
        return () => {
            this.listeners[event].delete(listener);
        };
    }
}
exports.UiTheme = UiTheme;
function colorTextEmphasized(colorPair) {
    var _a, _b;
    return (colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) ? (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? Math.min(l + 15, 100) : l - 10),
    }) : (_b = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? s : Math.min(s + 15, 100)),
        l: (l) => (l > 50 ? Math.max(l - 77.5, 0) : 98.3),
    });
}
exports.colorTextEmphasized = colorTextEmphasized;
function colorTextSubdued(colorPair) {
    var _a, _b;
    return (colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) ? (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? Math.max(l - 35, 0) : l - 15),
    }) : (_b = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? Math.max(s - 55, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 49.9, 10) : Math.min(l + 63.2, 90)),
    });
}
exports.colorTextSubdued = colorTextSubdued;
function colorHovered(colorPair) {
    var _a;
    return (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l - 10,
    });
}
function colorPressed(colorPair) {
    var _a;
    return (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l - 10,
    });
}
function colorText(colorPair) {
    var _a, _b;
    return ((_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) !== null && _a !== void 0 ? _a : (_b = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _b === void 0 ? void 0 : _b.adjust({
        l: (l) => (l > 50 ? 4 : 96),
    }));
}
function colorTextHovered(colorPair) {
    var _a;
    return (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l - 10,
    });
}
function colorTextPressed(colorPair) {
    var _a;
    return (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l - 10,
    });
}
function colorsFromOverrides(overrideColors) {
    return Object.keys(overrideColors).reduce((colors, key) => {
        const colorOrPair = overrideColors[key];
        if (colorOrPair == null)
            return colors;
        const { background, foreground } = colorOrPair;
        return Object.assign(Object.assign({}, colors), { [key]: {
                background: background ? normalizeColor(background) : undefined,
                foreground: foreground ? normalizeColor(foreground) : undefined,
            } });
    }, {});
}
function colorBorderEmphasized(colorPair) {
    var _a;
    return (_a = colorPair === null || colorPair === void 0 ? void 0 : colorPair.background) === null || _a === void 0 ? void 0 : _a.adjust({
        s: (s) => (s > 50 ? s : Math.min(s + 15, 100)),
        l: (l) => (l > 50 ? Math.max(l - 77.5, 0) : 98.3),
    });
}
exports.colorBorderEmphasized = colorBorderEmphasized;
function normalizeColor(color) {
    if (color instanceof hsluv_1.Hsl)
        return color;
    if (typeof color === 'string')
        return hsluv_1.parseHsl(color);
    return new hsluv_1.Hsl(...color);
}
const COLOR_MAP = {
    /* COLOR CANVAS */
    colorCanvas: ({ canvas }) => canvas === null || canvas === void 0 ? void 0 : canvas.background,
    colorCanvasText: ({ canvas }) => { var _a, _b; return (_a = canvas === null || canvas === void 0 ? void 0 : canvas.foreground) !== null && _a !== void 0 ? _a : (_b = canvas === null || canvas === void 0 ? void 0 : canvas.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? Math.max(s - 55, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)),
    }); },
    colorCanvasTextSubdued: ({ canvas }) => colorTextSubdued(canvas),
    colorCanvasTextEmphasized: ({ canvas }) => colorTextEmphasized(canvas),
    colorCanvasBorder: ({ canvas }) => { var _a; return (_a = canvas === null || canvas === void 0 ? void 0 : canvas.background) === null || _a === void 0 ? void 0 : _a.adjust({
        s: (s) => (s > 50 ? Math.max(s - 15, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 8.8, 0) : Math.min(l + 11.3, 90)),
    }); },
    colorCanvasBorderEmphasized: ({ canvas }) => colorBorderEmphasized(canvas),
    /* COLOR SURFACE 1 */
    colorSurfacePrimary: ({ surfacePrimary }) => surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.background,
    colorSurfacePrimaryDisabled: ({ surfacePrimary }) => { var _a; return (_a = surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)),
    }); },
    colorSurfacePrimaryText: ({ surfacePrimary }) => { var _a, _b; return (_a = surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.foreground) !== null && _a !== void 0 ? _a : (_b = surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? Math.max(s - 55, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)),
    }); },
    colorSurfacePrimaryTextSubdued: ({ surfacePrimary }) => colorTextSubdued(surfacePrimary),
    colorSurfacePrimaryTextEmphasized: ({ surfacePrimary }) => colorTextEmphasized(surfacePrimary),
    colorSurfacePrimaryBorder: ({ surfacePrimary }) => { var _a; return (_a = surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        s: (s) => (s > 50 ? Math.max(s - 15, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 8.8, 0) : Math.min(l + 11.3, 90)),
    }); },
    colorSurfacePrimaryBorderEmphasized: ({ surfacePrimary }) => colorBorderEmphasized(surfacePrimary),
    /* COLOR SURFACE 2 */
    colorSurfaceSecondary: ({ surfaceSecondary }) => surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.background,
    colorSurfaceSecondaryDisabled: ({ surfaceSecondary }) => { var _a; return (_a = surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)),
    }); },
    colorSurfaceSecondaryText: ({ surfaceSecondary }) => { var _a, _b; return (_a = surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.foreground) !== null && _a !== void 0 ? _a : (_b = surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? Math.max(s - 55, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)),
    }); },
    colorSurfaceSecondaryTextSubdued: ({ surfaceSecondary }) => colorTextSubdued(surfaceSecondary),
    colorSurfaceSecondaryTextEmphasized: ({ surfaceSecondary }) => colorTextEmphasized(surfaceSecondary),
    colorSurfaceSecondaryBorder: ({ surfaceSecondary }) => { var _a; return (_a = surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        s: (s) => (s > 50 ? Math.max(s - 15, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 8.8, 0) : Math.min(l + 11.3, 90)),
    }); },
    colorSurfaceSecondaryBorderEmphasized: ({ surfaceSecondary }) => colorBorderEmphasized(surfaceSecondary),
    /* COLOR SURFACE 3 */
    colorSurfaceTertiary: ({ surfaceTertiary }) => surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background,
    colorSurfaceTertiaryDisabled: ({ surfaceTertiary }) => { var _a; return (_a = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)),
    }); },
    colorSurfaceTertiarySubdued: ({ surfaceTertiary }) => { var _a; return (_a = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => (l > 50 ? l - 1.7 : Math.max(l - 5.2, 0)),
    }); },
    colorSurfaceTertiaryText: ({ surfaceTertiary }) => { var _a, _b; return (_a = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.foreground) !== null && _a !== void 0 ? _a : (_b = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background) === null || _b === void 0 ? void 0 : _b.adjust({
        s: (s) => (s > 50 ? Math.max(s - 55, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)),
    }); },
    colorSurfaceTertiaryTextSubdued: ({ surfaceTertiary }) => colorTextSubdued(surfaceTertiary),
    colorSurfaceTertiaryTextEmphasized: ({ surfaceTertiary }) => colorTextEmphasized(surfaceTertiary),
    colorSurfaceTertiaryBorder: ({ surfaceTertiary }) => { var _a; return (_a = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background) === null || _a === void 0 ? void 0 : _a.adjust({
        s: (s) => (s > 50 ? Math.max(s - 15, 0) : s),
        l: (l) => (l > 50 ? Math.max(l - 8.8, 0) : Math.min(l + 11.3, 90)),
    }); },
    colorSurfaceTertiaryBorderEmphasized: ({ surfaceTertiary }) => colorBorderEmphasized(surfaceTertiary),
    /* COLOR PRIMARY */
    colorPrimary: ({ primary }) => primary === null || primary === void 0 ? void 0 : primary.background,
    colorPrimaryHovered: ({ primary }) => colorHovered(primary),
    colorPrimaryPressed: ({ primary }) => colorPressed(primary),
    colorPrimaryText: ({ primary }) => colorText(primary),
    colorPrimaryTextHovered: ({ primary }) => colorTextHovered(primary),
    colorPrimaryTextPressed: ({ primary }) => colorTextPressed(primary),
    /* COLOR SECONDARY */
    colorSecondary: ({ secondary }) => secondary === null || secondary === void 0 ? void 0 : secondary.background,
    colorSecondaryHovered: ({ secondary }) => colorHovered(secondary),
    colorSecondaryPressed: ({ secondary }) => colorPressed(secondary),
    colorSecondaryText: ({ secondary }) => colorText(secondary),
    colorSecondaryTextHovered: ({ secondary }) => colorTextHovered(secondary),
    colorSecondaryTextPressed: ({ secondary }) => colorTextPressed(secondary),
    /* COLOR INTERACTIVE */
    colorInteractive: ({ interactive }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
    colorInteractiveHovered: ({ interactive }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
    colorInteractivePressed: ({ interactive }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
    colorInteractiveText: ({ interactive }) => interactive === null || interactive === void 0 ? void 0 : interactive.foreground,
    colorInteractiveTextHovered: ({ interactive }) => { var _a; return (_a = interactive === null || interactive === void 0 ? void 0 : interactive.foreground) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l + 10,
    }); },
    colorInteractiveTextPressed: ({ interactive }) => { var _a; return (_a = interactive === null || interactive === void 0 ? void 0 : interactive.foreground) === null || _a === void 0 ? void 0 : _a.adjust({
        l: (l) => l + 10,
    }); },
};
const TYPOGRAPHY_SCALE_MAP = {
    typographySizeXSmall: ({ base, ratio }) => base ? modularScale_1.modularScale(-1, base, ratio) : undefined,
    typographySizeSmall: ({ base, ratio }) => base ? modularScale_1.modularScale(-0.5, base, ratio) : undefined,
    typographySizeDefault: ({ base, ratio }) => base ? modularScale_1.modularScale(0, base, ratio) : undefined,
    typographySizeMedium: ({ base, ratio }) => base ? modularScale_1.modularScale(0.5, base, ratio) : undefined,
    typographySizeLarge: ({ base, ratio }) => base ? modularScale_1.modularScale(1, base, ratio) : undefined,
    typographySizeXLarge: ({ base, ratio }) => base ? modularScale_1.modularScale(2, base, ratio) : undefined,
    typographySizeXXLarge: ({ base, ratio }) => base ? modularScale_1.modularScale(3, base, ratio) : undefined,
};
const TYPOGRAPHY_SIZE_MAP = {
    xsmall: 'var(--x-typography-size-xsmall)',
    small: 'var(--x-typography-size-small)',
    base: 'var(--x-typography-size-default)',
    medium: 'var(--x-typography-size-medium)',
    large: 'var(--x-typography-size-large)',
    xlarge: 'var(--x-typography-size-xlarge)',
    xxlarge: 'var(--x-typography-size-xxlarge)',
};
const TYPOGRAPHY_CASE_MAP = {
    none: 'none',
    title: 'capitalize',
    upper: 'uppercase',
    lower: 'lowercase',
};
const TYPOGRAPHY_FONTS_MAP = {
    primary: 'var(--x-typography-primary-fonts)',
    secondary: 'var(--x-typography-secondary-fonts)',
};
const TYPOGRAPHY_KERNING_MAP = {
    base: 'normal',
    loose: '0.125em',
    xloose: '0.16em',
};
const TYPOGRAPHY_LINE_SIZE_MAP = {
    base: '1.3',
    large: '1.5',
};
const TYPOGRAPHY_PRIMARY_WEIGHT_MAP = {
    base: 'var(--x-typography-primary-weight-base)',
    bold: 'var(--x-typography-primary-weight-bold)',
};
const TYPOGRAPHY_SECONDARY_WEIGHT_MAP = {
    base: 'var(--x-typography-secondary-weight-base)',
    bold: 'var(--x-typography-secondary-weight-bold)',
};
const SPACING_RATIO = 1.225;
const SPACING_MAP = {
    spacingTight4X: ({ base }) => base ? modularScale_1.modularScale(-5, base, SPACING_RATIO) : undefined,
    spacingTight3X: ({ base }) => base ? modularScale_1.modularScale(-4, base, SPACING_RATIO) : undefined,
    spacingTight2X: ({ base }) => base ? modularScale_1.modularScale(-3, base, SPACING_RATIO) : undefined,
    spacingTight1X: ({ base }) => base ? modularScale_1.modularScale(-2, base, SPACING_RATIO) : undefined,
    spacingTight: ({ base }) => base ? modularScale_1.modularScale(-1, base, SPACING_RATIO) : undefined,
    spacingBase: ({ base }) => base ? modularScale_1.modularScale(0, base, SPACING_RATIO) : undefined,
    spacingLoose: ({ base }) => base ? modularScale_1.modularScale(1, base, SPACING_RATIO) : undefined,
    spacingLoose1X: ({ base }) => base ? modularScale_1.modularScale(2, base, SPACING_RATIO) : undefined,
    spacingLoose2X: ({ base }) => base ? modularScale_1.modularScale(3, base, SPACING_RATIO) : undefined,
    spacingLoose3X: ({ base }) => base ? modularScale_1.modularScale(4, base, SPACING_RATIO) : undefined,
    spacingLoose4X: ({ base }) => base ? modularScale_1.modularScale(5, base, SPACING_RATIO) : undefined,
};
const SIMPLE_BORDER_RADIUS_MAP = {
    none: 'var(--x-border-radius-none)',
    base: 'var(--x-border-radius-base)',
};
const BORDER_RADIUS_MAP = Object.assign(Object.assign({}, SIMPLE_BORDER_RADIUS_MAP), { fullyRounded: 'var(--x-border-radius-fully-rounded)' });
const BORDER_MAP = {
    full: 'var(--x-border-full)',
    blockEnd: 'var(--x-border-block-end)',
    none: 'var(--x-border-none)',
};
const OPTION_LIST_GAP_MAP = {
    base: 'var(--x-spacing-base)',
    tight: 'var(--x-spacing-tight4x)',
    none: '0',
};
const REVIEW_BLOCK_GAP_MAP = {
    base: 'var(--x-spacing-base)',
    tight: 'var(--x-spacing-tight4x)',
    none: '0',
};
const BUYER_JOURNEY_GAP_MAP = {
    base: 'var(--x-spacing-tight1x)',
    loose: 'var(--x-spacing-loose2x)',
};
function customPropertiesFromThemeConfiguration({ global, buyerJourney, colors, typographyScale, typographyPrimary, typographySecondary, controls, textFields, select, optionList, checkbox, reviewBlock, typographyStyle1, typographyStyle2, typographyStyle3, typographyStyle4, typographyStyle5, typographyStyle6, typographyStyle7, typographyStyle8, typographyStyle9, }) {
    var _a, _b, _c, _d, _e, _f;
    const globalTypographyLetterCase = maybeInMap(TYPOGRAPHY_CASE_MAP)(global.typographyLetterCase);
    const globalTypographyLineSize = maybeInMap(TYPOGRAPHY_LINE_SIZE_MAP)(global.typographyLineSize);
    const globalTypographyKerning = maybeInMap(TYPOGRAPHY_KERNING_MAP)(global.typographyKerning);
    const globalBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(global.borderRadius);
    const controlBorderRadius = maybeInMap(SIMPLE_BORDER_RADIUS_MAP)(controls.borderRadius);
    const textFieldBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(textFields.borderRadius);
    const selectBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(select.borderRadius);
    const optionListBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(optionList.borderRadius);
    const checkboxBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(checkbox.borderRadius);
    const reviewBlockBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(reviewBlock.borderRadius);
    const [textFieldBorder, selectBorder, checkboxBorder, optionListBorder] = [
        textFields.border,
        select.border,
        checkbox.border,
        optionList.border,
    ].map(maybeInMap(BORDER_MAP));
    const typographyPrimaryFonts = (_a = typographyPrimary.fonts) !== null && _a !== void 0 ? _a : undefined;
    const typographyPrimaryWeightBase = (_b = typographyPrimary.weightBase) !== null && _b !== void 0 ? _b : undefined;
    const typographyPrimaryWeightBold = (_c = typographyPrimary.weightBold) !== null && _c !== void 0 ? _c : undefined;
    const typographySecondaryFonts = (_d = typographySecondary.fonts) !== null && _d !== void 0 ? _d : undefined;
    const typographySecondaryWeightBase = (_e = typographySecondary.weightBase) !== null && _e !== void 0 ? _e : undefined;
    const typographySecondaryWeightBold = (_f = typographySecondary.weightBold) !== null && _f !== void 0 ? _f : undefined;
    const optionListBlockGap = maybeInMap(OPTION_LIST_GAP_MAP)(optionList.gap);
    const buyerJourneyInlineGap = maybeInMap(BUYER_JOURNEY_GAP_MAP)(buyerJourney.gap);
    const reviewBlockBlockGap = maybeInMap(REVIEW_BLOCK_GAP_MAP)(reviewBlock.gap);
    const reviewBlockBorder = maybeInMap(BORDER_MAP)(reviewBlock.border);
    const [style1TypographySize, style1TypographyCase, style1TypographyFonts, style1TypographyWeight, style1TypographyLineSize, style1TypographyKerning, style2TypographySize, style2TypographyCase, style2TypographyFonts, style2TypographyWeight, style2TypographyLineSize, style2TypographyKerning, style3TypographySize, style3TypographyCase, style3TypographyFonts, style3TypographyWeight, style3TypographyLineSize, style3TypographyKerning, style4TypographySize, style4TypographyCase, style4TypographyFonts, style4TypographyWeight, style4TypographyLineSize, style4TypographyKerning, style5TypographySize, style5TypographyCase, style5TypographyFonts, style5TypographyWeight, style5TypographyLineSize, style5TypographyKerning, style6TypographySize, style6TypographyCase, style6TypographyFonts, style6TypographyWeight, style6TypographyLineSize, style6TypographyKerning, style7TypographySize, style7TypographyCase, style7TypographyFonts, style7TypographyWeight, style7TypographyLineSize, style7TypographyKerning, style8TypographySize, style8TypographyCase, style8TypographyFonts, style8TypographyWeight, style8TypographyLineSize, style8TypographyKerning, style9TypographySize, style9TypographyCase, style9TypographyFonts, style9TypographyWeight, style9TypographyLineSize, style9TypographyKerning,] = [
        typographyStyle1,
        typographyStyle2,
        typographyStyle3,
        typographyStyle4,
        typographyStyle5,
        typographyStyle6,
        typographyStyle7,
        typographyStyle8,
        typographyStyle9,
    ]
        .map((style) => [
        maybeInMap(TYPOGRAPHY_SIZE_MAP)(style.size),
        maybeInMap(TYPOGRAPHY_CASE_MAP)(style.letterCase),
        maybeInMap(TYPOGRAPHY_FONTS_MAP)(style.fonts),
        style.weight
            ? typographyWeightMapping(style.fonts ? style.fonts : 'secondary', style.weight)
            : undefined,
        maybeInMap(TYPOGRAPHY_LINE_SIZE_MAP)(style.lineSize),
        maybeInMap(TYPOGRAPHY_KERNING_MAP)(style.kerning),
    ])
        .reduce((accumulator, array) => [...accumulator, ...array], []);
    const customProperties = Object.assign(Object.assign(Object.assign(Object.assign({}, customPropertiesFromRoleColors(colorsFromOverrides(colors))), customPropertiesFromTypographyScale(typographyScale)), customPropertiesFromSpacing(typographyScale)), { typographyPrimaryFonts,
        typographyPrimaryWeightBase,
        typographyPrimaryWeightBold,
        typographySecondaryFonts,
        typographySecondaryWeightBase,
        typographySecondaryWeightBold,
        globalTypographyLetterCase,
        globalTypographyLineSize,
        globalTypographyKerning,
        globalBorderRadius,
        controlBorderRadius,
        checkboxBorder,
        checkboxBorderRadius,
        textFieldBorder,
        textFieldBorderRadius,
        selectBorderRadius,
        selectBorder,
        optionListBorderRadius,
        optionListBlockGap,
        optionListBorder,
        reviewBlockBorderRadius,
        reviewBlockBlockGap,
        reviewBlockBorder,
        buyerJourneyInlineGap,
        style1TypographySize,
        style1TypographyCase,
        style1TypographyFonts,
        style1TypographyWeight,
        style1TypographyLineSize,
        style1TypographyKerning,
        style2TypographySize,
        style2TypographyCase,
        style2TypographyFonts,
        style2TypographyWeight,
        style2TypographyLineSize,
        style2TypographyKerning,
        style3TypographySize,
        style3TypographyCase,
        style3TypographyFonts,
        style3TypographyWeight,
        style3TypographyLineSize,
        style3TypographyKerning,
        style4TypographySize,
        style4TypographyCase,
        style4TypographyFonts,
        style4TypographyWeight,
        style4TypographyLineSize,
        style4TypographyKerning,
        style5TypographySize,
        style5TypographyCase,
        style5TypographyFonts,
        style5TypographyWeight,
        style5TypographyLineSize,
        style5TypographyKerning,
        style6TypographySize,
        style6TypographyCase,
        style6TypographyFonts,
        style6TypographyWeight,
        style6TypographyLineSize,
        style6TypographyKerning,
        style7TypographySize,
        style7TypographyCase,
        style7TypographyFonts,
        style7TypographyWeight,
        style7TypographyLineSize,
        style7TypographyKerning,
        style8TypographySize,
        style8TypographyCase,
        style8TypographyFonts,
        style8TypographyWeight,
        style8TypographyLineSize,
        style8TypographyKerning,
        style9TypographySize,
        style9TypographyCase,
        style9TypographyFonts,
        style9TypographyWeight,
        style9TypographyLineSize,
        style9TypographyKerning });
    for (const key of Object.keys(customProperties)) {
        if (customProperties[key] == null) {
            delete customProperties[key];
        }
    }
    return customProperties;
}
function customPropertiesFromRoleColors(colors) {
    var _a;
    const customProperties = {};
    for (const property of Object.keys(COLOR_MAP)) {
        const color = (_a = COLOR_MAP[property]) === null || _a === void 0 ? void 0 : _a.call(COLOR_MAP, colors);
        if (color != null)
            customProperties[property] = hsluv_1.toRgb(color);
    }
    return customProperties;
}
function customPropertiesFromTypographyScale(scale) {
    var _a;
    const customProperties = {};
    for (const property of Object.keys(TYPOGRAPHY_SCALE_MAP)) {
        const fontSize = (_a = TYPOGRAPHY_SCALE_MAP[property]) === null || _a === void 0 ? void 0 : _a.call(TYPOGRAPHY_SCALE_MAP, scale);
        if (fontSize != null)
            customProperties[property] = fontSize;
    }
    return customProperties;
}
function customPropertiesFromSpacing(scale) {
    var _a;
    const customProperties = {};
    for (const property of Object.keys(SPACING_MAP)) {
        const spacing = (_a = SPACING_MAP[property]) === null || _a === void 0 ? void 0 : _a.call(SPACING_MAP, scale);
        if (spacing != null)
            customProperties[property] = spacing;
    }
    return customProperties;
}
function typographyWeightMapping(fontStack, weight) {
    return fontStack === 'primary'
        ? TYPOGRAPHY_PRIMARY_WEIGHT_MAP[weight]
        : TYPOGRAPHY_SECONDARY_WEIGHT_MAP[weight];
}
function maybeInMap(map) {
    return (value) => (value ? map[value] : undefined);
}
